@@ -62,6 +62,9 @@ push @::global_suppressions,
      qr(WSREP: Ignoring error*),
      qr(WSREP: Failed to remove page file .*),
      qr(WSREP: wsrep_sst_method is set to 'mysqldump' yet mysqld bind_address is set to .*),
+     qr|WSREP: Sending JOIN failed: -107 \(Transport endpoint is not connected\). Will retry in new primary component.|,
+     qr|WSREP: Trying to continue unpaused monitor|,
+     qr|WSREP: Wait for gtid returned error 3 while waiting for prior transactions to commit before setting position|,
    );
 
 sub skip_combinations {
